# frozen_string_literal: true

require_relative 'rgloader/rgloader_v320/rg_loader_320'
require_relative 'src/constants/error_constants'

module Modelur
  def self.warn_in_timer(*warnings)
    UI.start_timer(0, false) do
      warn "\nMODELUR WARN IN TIMER START ==================="
      warnings.each do |warning|
        warn warning
      end
      warn "\nMODELUR WARN IN TIMER END ====================="
    end
  end

  Modelur::RgLoader320.reload!

  module Bootstrap
    def self.validate_modelur
      raise StandardError, ERR_MODELUR_EXPIRED if Time.now.to_i > MODELUR_EXPIRATION

      su_version = SU_VERSION_NUMBER / 100000000
      raise StandardError, ERR_INCOMPATIBLE_SU_VERSION if su_version < MIN_SU_VERSION or su_version > MAX_SU_VERSION
    end
  end

  begin
    Bootstrap.validate_modelur
    GC.disable
    require_relative 'src/utils/solidify'
    raise SecurityError, ERROR_012 unless Solidify.solid?(Solidify)

    require_relative 'src/initialize_plugin'
    GC.enable
  rescue StandardError, SecurityError => e
    LOAD_ERROR = e
    require_relative 'bootstrap_fallback'
    GC.enable
  end
end
